<?php

namespace Litecms\Ourportfolio\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Ourportfolio\Models\Ourportfolio;

class OurportfolioPolicy
{

    /**
     * Determine if the given user can view the ourportfolio.
     *
     * @param UserPolicy $user
     * @param Ourportfolio $ourportfolio
     *
     * @return bool
     */
    public function view(UserPolicy $user, Ourportfolio $ourportfolio)
    {
        if ($user->canDo('ourportfolio.ourportfolio.view') && $user->isAdmin()) {
            return true;
        }

        return $ourportfolio->user_id == user_id() && $ourportfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ourportfolio.
     *
     * @param UserPolicy $user
     * @param Ourportfolio $ourportfolio
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ourportfolio.ourportfolio.create');
    }

    /**
     * Determine if the given user can update the given ourportfolio.
     *
     * @param UserPolicy $user
     * @param Ourportfolio $ourportfolio
     *
     * @return bool
     */
    public function update(UserPolicy $user, Ourportfolio $ourportfolio)
    {
        if ($user->canDo('ourportfolio.ourportfolio.edit') && $user->isAdmin()) {
            return true;
        }

        return $ourportfolio->user_id == user_id() && $ourportfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ourportfolio.
     *
     * @param UserPolicy $user
     * @param Ourportfolio $ourportfolio
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Ourportfolio $ourportfolio)
    {
        return $ourportfolio->user_id == user_id() && $ourportfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ourportfolio.
     *
     * @param UserPolicy $user
     * @param Ourportfolio $ourportfolio
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Ourportfolio $ourportfolio)
    {
        if ($user->canDo('ourportfolio.ourportfolio.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ourportfolio.
     *
     * @param UserPolicy $user
     * @param Ourportfolio $ourportfolio
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Ourportfolio $ourportfolio)
    {
        if ($user->canDo('ourportfolio.ourportfolio.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
